==> devextreme-22.1.1-alpha-21355-0313.tgz: package/cjs/ui/tab_panel/item.js <==
/**
 * DevExtreme (cjs/ui/tab_panel/item.js)
 * Version: 22.1.0 (build 21355-0313)
 * Build date: Tue Dec 21 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _item = _interopRequireDefault(require("../collection/item"));
var _common = require("../../core/utils/common");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var TabPanelItem = function(_CollectionWidgetItem) {
    _inheritsLoose(TabPanelItem, _CollectionWidgetItem);

    function TabPanelItem() {
        return _CollectionWidgetItem.apply(this, arguments) || this
    }
    var _proto = TabPanelItem.prototype;
    _proto._renderWatchers = function() {
        this._startWatcher("badge", _common.noop);
        return _CollectionWidgetItem.prototype._renderWatchers.call(this)
    };
    return TabPanelItem
}(_item.default);
exports.default = TabPanelItem;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-22.2.1-alpha-22245-0308.tgz: package/cjs/ui/tab_panel/item.js <==
/**
 * DevExtreme (cjs/ui/tab_panel/item.js)
 * Version: 22.2.0 (build 22245-0308)
 * Build date: Fri Sep 02 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _item = _interopRequireDefault(require("../collection/item"));
var _common = require("../../core/utils/common");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var TabPanelItem = function(_CollectionWidgetItem) {
    _inheritsLoose(TabPanelItem, _CollectionWidgetItem);

    function TabPanelItem() {
        return _CollectionWidgetItem.apply(this, arguments) || this
    }
    var _proto = TabPanelItem.prototype;
    _proto._renderWatchers = function() {
        this._startWatcher("badge", _common.noop);
        return _CollectionWidgetItem.prototype._renderWatchers.call(this)
    };
    return TabPanelItem
}(_item.default);
exports.default = TabPanelItem;
module.exports = exports.default;
module.exports.default = exports.default;
